(accepts-gzip? {:keys [headers]})Tests if the request indicates that the client can accept a gzipped response
Tests if the request indicates that the client can accept a gzipped response
(content-encoding? {:keys [headers]})Tests if the provided response has a content-encoding header
Tests if the provided response has a content-encoding header
(wrap-gzip handler)Ring middleware that GZIPs response if client can handle it.
Ring middleware that GZIPs response if client can handle it.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |